scalar_from_bytes_mod_order

Function scalar_from_bytes_mod_order 

pub fn scalar_from_bytes_mod_order(bytes: &[u8; 32]) -> Scalar
Decode a scalar from 32 bytes, reducing mod ℓ. Used for inputs like the local share where the encoding may have come from a wide hash.